Learn R Programming

chisquare (version 1.2)

compute_gk_tau_se: Compute the standard error of Goodman-Kruskal tau for the input table

Description

This ancillary function compute the standard error of Goodman-Kruskal tau. In the code, some annotations refer to equations from Bishop, Y. M., Fienberg, S. E., & Holland, P. W. (2007). Discrete Multivariate Analysis: Theory and Practice. Springer. ISBN 9780387728056

Usage

compute_gk_tau_se(cont_table)

Value

List with two components: the se of tau considering the row variable as dependent, and the se of tau when the column variable is considered dependent

Arguments

cont_table

Input cross-tabulation.