Learn R Programming

chisquare (version 1.2)

compute_median_polish_residuals: Ancillary function for median polish analysis

Description

This ancillary function compute the standardised Pearson median polish residual and their adjusted version, following Simonoff 2003 and Mosteller-Parunak 1985.

Usage

compute_median_polish_residuals(df)

Value

List containing robust expected counts, standardised and adjusted standardised Pearson median polish residuals

Arguments

df

Input cross-tabulation.