This ancillary function compute the standard error of Goodman-Kruskal tau. In the code, some annotations refer to equations from Bishop, Y. M., Fienberg, S. E., & Holland, P. W. (2007). Discrete Multivariate Analysis: Theory and Practice. Springer. ISBN 9780387728056
compute_gk_tau_se(cont_table)List with two components: the se of tau considering the row variable as dependent, and the se of tau when the column variable is considered dependent
Input cross-tabulation.